@@ -146,6 +146,16 @@ fn translate_term(t: &ModusTerm) -> (IRTerm, Vec<logic::Literal>) {
         }
         ModusTerm::UserVariable(v) => (IRTerm::UserVariable(v.to_owned()), Vec::new()),
         ModusTerm::AnonymousVariable => (sld::Auxiliary::aux(true), Vec::new()),
+        ModusTerm::Array(_, ts) => {
+            let mut new_terms = Vec::new();
+            let mut new_literals = Vec::new();
+            for term in ts {
+                let (new_term, new_lits) = translate_term(term);
+                new_terms.push(new_term);
+                new_literals.extend(new_lits);
+            }
+            (IRTerm::Array(new_terms), new_literals)
+        }
     }
 }
 
